@@ -1,14 +1,8 @@
-# {{{ BEGIN BPS TAGGED BLOCK
+# BEGIN LICENSE BLOCK
 # 
-# COPYRIGHT:
-#  
-# This software is Copyright (c) 1996-2004 Best Practical Solutions, LLC 
-#                                          <jesse@bestpractical.com>
+# Copyright (c) 1996-2003 Jesse Vincent <jesse@bestpractical.com>
 # 
-# (Except where explicitly superseded by other copyright notices)
-# 
-# 
-# LICENSE:
+# (Except where explictly superceded by other copyright notices)
 # 
 # This work is made available to you under the terms of Version 2 of
 # the GNU General Public License. A copy of that license should have
@@ -20,29 +14,13 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # General Public License for more details.
 # 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# Unless otherwise specified, all modifications, corrections or
+# extensions to this work which alter its source code become the
+# property of Best Practical Solutions, LLC when submitted for
+# inclusion in the work.
 # 
 # 
-# CONTRIBUTION SUBMISSION POLICY:
-# 
-# (The following paragraph is not intended to limit the rights granted
-# to you to modify and distribute this software under the terms of
-# the GNU General Public License and is only of importance to you if
-# you choose to contribute your changes and enhancements to the
-# community by submitting them to Best Practical Solutions, LLC.)
-# 
-# By intentionally submitting any modifications, corrections or
-# derivatives to this work, or any other work intended for use with
-# Request Tracker, to Best Practical Solutions, LLC, you confirm that
-# you are the copyright holder for those contributions and you grant
-# Best Practical Solutions,  LLC a nonexclusive, worldwide, irrevocable,
-# royalty-free, perpetual, license to use, copy, create derivative
-# works based on those contributions, and sublicense and distribute
-# those contributions and any derivatives thereof.
-# 
-# }}} END BPS TAGGED BLOCK
+# END LICENSE BLOCK
 =head1 NAME
 
   RT::Action::Generic - a generic baseclass for RT Actions
@@ -66,9 +44,6 @@ ok (require RT::Action::Generic);
 package RT::Action::Generic;
 
 use strict;
-use Scalar::Util;
-
-use base qw/RT::Base/;
 
 # {{{ sub new 
 sub new  {
@@ -81,6 +56,13 @@ sub new  {
 }
 # }}}
 
+# {{{ sub new 
+sub loc {
+    my $self = shift;
+    return $self->{'ScripObj'}->loc(@_);
+}
+# }}}
+
 # {{{ sub _Init 
 sub _Init  {
   my $self = shift;
@@ -90,7 +72,6 @@ sub _Init  {
 	       TemplateObj => undef,
 	       Argument => undef,
 	       Type => undef,
-            CurrentUser => undef,
 	       @_ );
   
   
@@ -100,16 +81,6 @@ sub _Init  {
   $self->{'TransactionObj'} = $args{'TransactionObj'};
   $self->{'TemplateObj'} = $args{'TemplateObj'};
   $self->{'Type'} = $args{'Type'};
-  $self->CurrentUser( $args{'CurrentUser'});
-    Scalar::Util::weaken($self->{'ScripObj'});
-    Scalar::Util::weaken($self->{'TicketObj'});
-    Scalar::Util::weaken($self->{'TemplateObj'});
-    Scalar::Util::weaken($self->{'TransactionObj'});
-
-
-
-
-
 }
 # }}}
 
