@@ -443,6 +443,11 @@ sub FromSQL {
   my ($self,$query) = @_;
 
   $self->CleanSlate;
+  {
+    # preserve first_row and show_rows across the CleanSlate
+    local($self->{'first_row'}, $self->{'show_rows'});
+    $self->CleanSlate;
+  }
   $self->_InitSQL();
 
   return (1,$self->loc("No Query")) unless $query;
