@@ -221,10 +221,10 @@ sub Content {
             $content = $wrapper->wrap($content);
         }
 
+        $content =~ s/^/> /gm;
         $content = '['
           . $self->CreatorObj->Name() . ' - '
-          . $self->CreatedAsString() . "]:\n\n" . $content . "\n\n";
-        $content =~ s/^/> /gm;
+          . $self->CreatedAsString() . "]:\n" . $content . "\n\n";
 
     }
 
